@@ -1,7 +1,7 @@
 package ExtUtils::MM_Any;
 
 use strict;
-our $VERSION = '6.76';
+our $VERSION = '6.80';
 
 use Carp;
 use File::Spec;
@@ -532,7 +532,7 @@ clean :: clean_subdirs
 #                    $(INST_BIN) $(INST_SCRIPT)
 #                    $(INST_MAN1DIR) $(INST_MAN3DIR)
 #                    $(INST_LIBDIR) $(INST_ARCHLIBDIR) $(INST_AUTODIR)
-#                    $(INST_STATIC) $(INST_DYNAMIC) $(INST_BOOT)
+#                    $(INST_STATIC) $(INST_DYNAMIC)
 #                 );
 
 
@@ -727,7 +727,7 @@ sub dynamic {
 
     my($self) = shift;
     '
-dynamic :: $(FIRST_MAKEFILE) $(INST_DYNAMIC) $(INST_BOOT)
+dynamic :: $(FIRST_MAKEFILE) $(BOOTSTRAP) $(INST_DYNAMIC)
 	$(NOECHO) $(NOOP)
 ';
 }
@@ -2045,7 +2045,9 @@ Defines at least these macros.
   RM_RF             Remove a directory
   TOUCH             Update a file's timestamp
   TEST_F            Test for a file's existence
+  TEST_S            Test the size of a file
   CP                Copy a file
+  CP_NONEMPTY       Copy a file if it is not empty
   MV                Move a file
   CHMOD             Change permissions on a file
   FALSE             Exit with non-zero
@@ -2067,6 +2069,8 @@ sub init_tools {
     $self->{RM_F}     ||= $self->oneliner('rm_f',  ["-MExtUtils::Command"]);
     $self->{RM_RF}    ||= $self->oneliner('rm_rf', ["-MExtUtils::Command"]);
     $self->{TEST_F}   ||= $self->oneliner('test_f', ["-MExtUtils::Command"]);
+    $self->{TEST_S}   ||= $self->oneliner('test_s', ["-MExtUtils::Command::MM"]);
+    $self->{CP_NONEMPTY} ||= $self->oneliner('cp_nonempty', ["-MExtUtils::Command::MM"]);
     $self->{FALSE}    ||= $self->oneliner('exit 1');
     $self->{TRUE}     ||= $self->oneliner('exit 0');
 
@@ -2214,6 +2218,7 @@ sub tools_other {
                       USEMAKEFILE
                       PM_FILTER
                       FIXIN
+                      CP_NONEMPTY
                     } )
     {
         next unless defined $self->{$tool};
@@ -2366,8 +2371,8 @@ Used on the t/*.t files.
 sub test_via_harness {
     my($self, $perl, $tests) = @_;
 
-    return qq{\t$perl "-MExtUtils::Command::MM" }.
-           qq{"-e" "test_harness(\$(TEST_VERBOSE), '\$(INST_LIB)', '\$(INST_ARCHLIB)')" $tests\n};
+    return qq{\t$perl "-MExtUtils::Command::MM" "-MTest::Harness" }.
+           qq{"-e" "undef *Test::Harness::Switches; test_harness(\$(TEST_VERBOSE), '\$(INST_LIB)', '\$(INST_ARCHLIB)')" $tests\n};
 }
 
 =head3 test_via_script
