@@ -3,12 +3,9 @@
 package MyIterator;
 
 use strict;
-use vars '@ISA';
+use warnings;
 
-use MyCustom;
-use TAP::Parser::Iterator;
-
-@ISA = qw( TAP::Parser::Iterator MyCustom );
+use parent qw( TAP::Parser::Iterator MyCustom );
 
 sub _initialize {
     my $self = shift;
