@@ -31,8 +31,10 @@ our @EXPORT_OK  = qw(
                      hash_seed hash_value hv_store
                      bucket_stats bucket_info bucket_array
                      lock_hash_recurse unlock_hash_recurse
+
+                     hash_traversal_mask
                     );
-our $VERSION = '0.14';
+our $VERSION = '0.16';
 require XSLoader;
 XSLoader::load();
 
@@ -76,6 +78,8 @@ Hash::Util - A selection of general-utility hash subroutines
                      hash_seed hash_value hv_store
                      bucket_stats bucket_info bucket_array
                      lock_hash_recurse unlock_hash_recurse
+
+                     hash_traversal_mask
                    );
 
   %hash = (foo => 42, bar => 23);
@@ -105,6 +109,10 @@ Hash::Util - A selection of general-utility hash subroutines
 
   my $int_hash_value = hash_value( 'string' );
 
+  my $mask= hash_traversal_mask(%hash);
+
+  hash_traversal_mask(%hash,1234);
+
 =head1 DESCRIPTION
 
 C<Hash::Util> and C<Hash::Util::FieldHash> contain special functions
@@ -525,15 +533,29 @@ Fields are as follows:
     0: Number of keys in the hash
     1: Number of buckets in the hash
     2: Number of used buckets in the hash
-    3: Percent of buckets used
-    4: Percent of keys which are in collision
-    5: Average bucket length
-    6: Standard Deviation of bucket lengths.
+    3: Hash Quality Score
+    4: Percent of buckets used
+    5: Percent of keys which are in collision
+    6: Average bucket length
+    7: Standard Deviation of bucket lengths.
     rest : list of counts, Kth element is the number of buckets
            with K keys in it.
 
 See also bucket_info() and bucket_array().
 
+Note that Hash Quality Score would be 1 for an ideal hash, numbers
+close to and below 1 indicate good hashing, and number significantly
+above indicate a poor score. In practice it should be around 0.95 to 1.05.
+It is defined as:
+
+ $score= sum( $count[$length] * ($length * ($length + 1) / 2) )
+            /
+            ( ( $keys / 2 * $buckets ) *
+              ( $keys + ( 2 * $buckets ) - 1 ) )
+
+The formula is from the Red Dragon book (reformulated to use the data available)
+and is documented at L<http://www.strchr.com/hash_functions>
+
 =item B<bucket_array>
 
     my $array= bucket_array(\%hash);
@@ -558,13 +580,20 @@ sub bucket_stats {
     my ($hash) = @_;
     my ($keys, $buckets, $used, @length_counts) = bucket_info($hash);
     my $sum;
-    $sum += ($length_counts[$_] * $_) for 0 .. $#length_counts;
+    my $score;
+    for (0 .. $#length_counts) {
+        $sum += ($length_counts[$_] * $_);
+        $score += $length_counts[$_] * ( $_ * ($_ + 1 ) / 2 );
+    }
+    $score = $score /
+             (( $keys / (2 * $buckets )) * ( $keys + ( 2 * $buckets ) - 1 ))
+                 if $keys;
     my $mean= $sum/$buckets;
     $sum= 0;
     $sum += ($length_counts[$_] * (($_-$mean)**2)) for 0 .. $#length_counts;
 
     my $stddev= sqrt($sum/$buckets);
-    return $keys, $buckets, $used, $keys ? ($used/$buckets, ($keys-$used)/$keys, $mean, $stddev, @length_counts) : ();
+    return $keys, $buckets, $used, $keys ? ($score, $used/$buckets, ($keys-$used)/$keys, $mean, $stddev, @length_counts) : ();
 }
 
 =item B<hv_store>
@@ -576,6 +605,20 @@ sub bucket_stats {
 
 Stores an alias to a variable in a hash instead of copying the value.
 
+=item B<hash_traversal_mask>
+
+As of Perl 5.18 every hash has its own hash traversal order, and this order
+changes every time a new element is inserted into the hash. This functionality
+is provided by maintaining an unsigned integer mask (U32) which is xor'ed
+with the actual bucket id during a traversal of the hash buckets using keys(),
+values() or each().
+
+You can use this subroutine to get and set the traversal mask for a specific
+hash. Setting the mask ensures that a given hash will produce the same key
+order. B<Note> that this does B<not> guarantee that B<two> hashes will produce
+the same key order for the same hash seed and traversal mask, items that
+collide into one bucket may have different orders regardless of this setting.
+
 =back
 
 =head2 Operating on references to hashes.
